//Inspiré de l'exemple "ILI9341Test" de la librairie XPT2046 disponible dans Arduino IDE
// adapté par Électro-Bidouilleur, Juin 2022

#include "Adafruit_ILI9341.h"
#include "Adafruit_GFX.h"
#include <XPT2046_Touchscreen.h>

// Voici les connexions sur un Rasprerry Pi Pico. Les numéros indiqués correspondent aux appellations GPxx du brochage.
#define TFT_DC 21
#define TFT_CS 17
#define TFT_MOSI 19
#define TFT_CLK 18
#define TFT_RST 20
#define TFT_MISO 16
#define TCS_PIN  22
#define TIRQ_PIN  26

// Utilisation du port SPI intégré (port matériel) du Pico. Il faut spécifier la position des broches CS, DC et RST pour l'affichage.
Adafruit_ILI9341 tft = Adafruit_ILI9341(TFT_CS, TFT_DC,TFT_RST);

// Implémentation de la lecture tactile en utilisant la broche IRQ
XPT2046_Touchscreen ts(TCS_PIN, TIRQ_PIN);  // Param 2 - Touch IRQ Pin - interrupt enabled polling


// Fonction d'initialisation, style Arduino
void setup() 
{
  pinMode(TCS_PIN,OUTPUT);                  // S'assurer que les broches CS sont au niveau haut pour commencer
  digitalWrite(TCS_PIN,HIGH);               //    "
  pinMode(TFT_CS,OUTPUT);
  digitalWrite(TFT_CS,HIGH);

  Serial.begin(38400);                      // Initialiser le port série
  tft.begin();                              // Démarrer l'instance d'écran
  tft.fillScreen(ILI9341_BLACK);            // Effacement de l'écran
  ts.begin();                               // Démarrer l'instance de détection tactile
  while (!Serial && (millis() <= 1000));    // Une pause d'au moins 1 seconde
}

boolean wastouched = true;                  // Simuler un toucher antérieur pour le démarrage


// Boucle perpétuelle, style Arduino
void loop() 
{
  boolean istouched = ts.touched();         // Lecture de la détection de toucher
  if (istouched)                            // Touché ?
  {                                         // Oui
    TS_Point p = ts.getPoint();             // Obtenir les coordonnées de toucher
    if (!wastouched)                        // Déjà en train de toucher?
    {                                       // Non
      tft.fillScreen(ILI9341_BLACK);    
      tft.setTextColor(ILI9341_YELLOW);
      tft.setTextSize(3);      
      tft.setCursor(60, 80);
      tft.print("Contact");
    }
    tft.fillRect(100, 150, 140, 60, ILI9341_BLACK);     // Effacer les coordonnées affichées
    tft.setTextColor(ILI9341_GREEN);                    // Afficher les nouvelles coordonnées
    tft.setTextSize(3);                                 //      "
    tft.setCursor(50, 150);
    tft.print("X = ");
    tft.print(p.x);
    tft.setCursor(50, 180);
    tft.print("Y = ");
    tft.print(p.y);
    Serial.print(", x = ");
    Serial.print(p.x);
    Serial.print(", y = ");
    Serial.println(p.y);
  } 
  else                                      // Pas touché
  {
    if (wastouched)                         // Précedemment touché?
    {                                       // Oui
      tft.fillScreen(ILI9341_BLACK);        // Effacer l'écran
      tft.setTextColor(ILI9341_RED);        // Afficher le message "Pas Contact"
      tft.setTextSize(3);                   //     "
      tft.setCursor(100, 70);
      tft.print("Pas");
      tft.setCursor(60, 100);
      tft.print("Contact");
    }
    Serial.println("Pas Contact");
  }
  wastouched = istouched;                   // Mise à jour du fanion de toucher antérieur
  delay(50);                                // Petite pause pour rendre le tout plus lisible
}
